%define rel	1

Name:		subtitlecomposer
Version:	0.8.1
Release:	%mkrel %{rel}
Summary:	A text-based subtitles editor
License:	GPLv2+
Group:		Text tools
URL:		https://subtitlecomposer.kde.org/
Source0:	https://download.kde.org/stable/subtitlecomposer/%{name}-%{version}.tar.xz
# (ahmad) fix the mimetypes installed by subtitlecompoer:
# - no need to duplicate the ones already available in the freedesktop specs
# - .txt files are not necessarily subtitles files
Patch0:		subtitlecomposer-0.6.6-mimetypes.patch

ExcludeArch:	i586

BuildRequires:	kf6-rpm-macros

BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Qml)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)

BuildRequires:	cmake(KF6Config)
BuildRequires:	cmake(KF6ConfigWidgets)
BuildRequires:	cmake(KF6CoreAddons)
BuildRequires:	cmake(KF6I18n)
BuildRequires:	cmake(KF6KIO)
BuildRequires:	cmake(KF6XmlGui)
BuildRequires:	cmake(KF6Sonnet)
BuildRequires:	cmake(KF6TextWidgets)
BuildRequires:	cmake(KF6WidgetsAddons)

BuildRequires:	pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:	pkgconfig(icu-io)
BuildRequires:	pkgconfig(libxine)
BuildRequires:	pkgconfig(mpv)
BuildRequires:	pkgconfig(pocketsphinx)
BuildRequires:	gettext
BuildRequires:	ffmpeg-devel

# needed dependencies (mga#20830)
Requires:	kio
Requires:	kio-extras

%description
A text-based subtitles editor that supports basic operations as well as more
advanced ones, aiming to become an improved version of Subtitle Workshop for
every platform supported by KF6 (KDE Frameworks 6).

Features:

  * Support for multiple formats, including SubRip, MicroDVD, SSA/ASS
    (without advanced styles), MPlayer, TMPlayer and YouTube captions.
  * Live preview of subtitles and video with support for multiple backends
    (GStreamer, MPlayer/2, MPV, Xine, Phonon), audio channel selection and
    full screen mode.
  * Time shifting and adjusting, lines duration calculation, synchronization
    with video, etc.
  * Working with original subtitle and translation.
  * Texts styles (italic, bold, underline, stroke, color), spell checking,
    automatic translation (using Google services), etc.
  * Joining and splitting of files.
  * Automatic detection of errors.
  * Editing of subtitles through scripting (Ruby, Python, JavaScript and other
    languages supported by Kross).

%files -f %{name}.lang
%doc ChangeLog README.md
%license LICENSE
%{_kf6_bindir}/%{name}
%{_kf6_applicationdir}/org.kde.%{name}.desktop
%config(noreplace) %{_kf6_sysconfdir}/xdg/%{name}rc
%{_kf6_datadir}/%{name}/
%{_kf6_iconsdir}/hicolor/*/*/*.png
%{_kf6_datadir}/mime/packages/%{name}.xml
%{_kf6_metainfodir}/org.kde.subtitlecomposer.appdata.xml

#------------------------------------------------------------------------------

%prep
%autosetup -p1

# fix permissions
chmod 644 ChangeLog

# fix shebangs
%py3_shebang_fix src/scripting/examples

%build
%cmake_kf6 -DQT_MAJOR_VERSION:BOOL=6 \
           -DKDE_INSTALL_LIBDIR=%{_lib}
%cmake_build

%install
%cmake_install

%find_lang %{name}

# we don't want these
find %{buildroot} -name '*.h' -delete


%changelog
* Thu Jun 13 2024 daviddavid <daviddavid> 0.8.1-1.mga10
+ Revision: 2072946
- new version: 0.8.1

* Fri Apr 05 2024 daviddavid <daviddavid> 0.8.0-4.mga10
+ Revision: 2054480
- update to latest git snapshot from 20240405
- use %%py3_shebang_fix macro

* Fri Nov 24 2023 daviddavid <daviddavid> 0.8.0-3.mga10
+ Revision: 2009507
- does not build with pochetsphinx now
- switch to Qt6/KF6
- enable pocketsphinx support

* Thu Nov 09 2023 daviddavid <daviddavid> 0.8.0-1.mga10
+ Revision: 2005263
- new version: 0.8.0

* Tue Oct 10 2023 daviddavid <daviddavid> 0.7.1-4.mga10
+ Revision: 1994116
- rebuild for icu73

* Sat Jan 07 2023 squidf <squidf> 0.7.1-3.mga9
+ Revision: 1931171
- Mass rebuild for icu 72.1

* Sat Jun 18 2022 squidf <squidf> 0.7.1-2.mga9
+ Revision: 1864905
- rebuild for icu 71.1

* Thu Apr 07 2022 luigiwalser <luigiwalser> 0.7.1-1.mga9
+ Revision: 1847531
- update to git snapshot from 20220401 to fix build with ffmpeg 5.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Tue Aug 03 2021 luigiwalser <luigiwalser> 0.7.0-10.mga9
+ Revision: 1738974
- rebuild for icu

* Thu Dec 17 2020 umeabot <umeabot> 0.7.0-9.mga8
+ Revision: 1659956
- Rebuild for new Qt5

* Mon Nov 30 2020 luigiwalser <luigiwalser> 0.7.0-8.mga8
+ Revision: 1650930
- rebuild for icu

* Wed Jul 01 2020 wally <wally> 0.7.0-7.mga8
+ Revision: 1601068
- rebuild for icu 67.1

* Thu May 28 2020 daviddavid <daviddavid> 0.7.0-6.mga8
+ Revision: 1588531
- switch appdata file to kf5_metainfo dir

* Sun Apr 05 2020 wally <wally> 0.7.0-5.mga8
+ Revision: 1564821
- fix python script shebangs
- rebuild for new icu 66.1
- build with new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Oct 05 2019 daviddavid <daviddavid> 0.7.0-3.mga8
+ Revision: 1449501
- rebuild for new icu 65.1

* Mon Sep 30 2019 daviddavid <daviddavid> 0.7.0-2.mga8
+ Revision: 1448223
- add missing dependencies on kio and kio-extras (mga#20830)

* Mon Jul 08 2019 daviddavid <daviddavid> 0.7.0-1.mga8
+ Revision: 1419477
- new version: 0.7.0

* Tue Apr 02 2019 umeabot <umeabot> 0.6.6-7.mga7
+ Revision: 1384919
- Qt5 Rebuild

* Sat Dec 29 2018 luigiwalser <luigiwalser> 0.6.6-6.mga7
+ Revision: 1346117
- rebuild for icu

* Wed Dec 26 2018 pterjan <pterjan> 0.6.6-5.mga7
+ Revision: 1345058
- Add missing BuildRequires
- Enable mpv support on arm

* Mon Aug 27 2018 daviddavid <daviddavid> 0.6.6-4.mga7
+ Revision: 1254934
- rebuild for new icu

* Mon Jun 11 2018 daviddavid <daviddavid> 0.6.6-3.mga7
+ Revision: 1236304
- add upstream patch to fix build with new Qt5 >= 5.11.0

* Sat Apr 28 2018 daviddavid <daviddavid> 0.6.6-2.mga7
+ Revision: 1223074
- rebuild for new ffmpeg 4.0

* Thu Feb 15 2018 daviddavid <daviddavid> 0.6.6-1.mga7
+ Revision: 1201574
- new version: 0.6.6
- rename and rediff mimetypes patch

* Thu Jan 04 2018 daviddavid <daviddavid> 0.6.5-2.mga7
+ Revision: 1190134
- rebuild for new icu

* Wed Oct 04 2017 daviddavid <daviddavid> 0.6.5-1.mga7
+ Revision: 1168138
- new version: 0.6.5

* Thu Mar 16 2017 mrambo3501 <mrambo3501> 0.6.4-4.mga6
+ Revision: 1093109
- Rebuild for icu-58.2

* Fri Dec 16 2016 daviddavid <daviddavid> 0.6.4-3.mga6
+ Revision: 1075686
- add patch1 to fix plugins install dir

* Sat May 14 2016 shlomif <shlomif> 0.6.4-2.mga6
+ Revision: 1015260
- Rebuild for the new UCI (new major)

* Sun May 08 2016 daviddavid <daviddavid> 0.6.4-1.mga6
+ Revision: 1011015
- new version: 0.6.4

* Mon Apr 04 2016 daviddavid <daviddavid> 0.6.3-1.mga6
+ Revision: 998288
- new version: 0.6.3

* Sat Mar 26 2016 daviddavid <daviddavid> 0.6.2-1.mga6
+ Revision: 995564
- new version: 0.6.2

* Wed Mar 16 2016 daviddavid <daviddavid> 0.6.1-1.mga6
+ Revision: 992036
- new version: 0.6.1

* Wed Feb 10 2016 daviddavid <daviddavid> 0.5.9-1.mga6
+ Revision: 953376
- new version: 0.5.9
- remove merged upstream patch

* Mon Feb 08 2016 daviddavid <daviddavid> 0.5.8-1.mga6
+ Revision: 943881
- new version: 0.5.8
- switch build to Qt5/kf5
- add mpv support
- add upstream patch to fix Italian translation
- improve description

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.5.7-4.mga6
+ Revision: 917923
- rebuild for icu

* Fri Oct 16 2015 daviddavid <daviddavid> 0.5.7-3.mga6
+ Revision: 892233
- add patch3 from debian to fix build failure for new gstreamer versions
- add patch4 from debian to fix crash: Sonnet::Dialog cannot handle empty buffers

* Sat Jul 25 2015 daviddavid <daviddavid> 0.5.7-2.mga6
+ Revision: 857248
- rebuild for icu 55

* Sun Nov 09 2014 daviddavid <daviddavid> 0.5.7-1.mga5
+ Revision: 796124
- new version: 0.5.7
- switch build to gstreamer1.0

* Wed Oct 15 2014 umeabot <umeabot> 0.5.6-4.mga5
+ Revision: 742908
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 0.5.6-3.mga5
+ Revision: 725239
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 0.5.6-2.mga5
+ Revision: 689573
- Mageia 5 Mass Rebuild

* Tue May 06 2014 daviddavid <daviddavid> 0.5.6-1.mga5
+ Revision: 620877
- update URL and Source0 for new upstream development
- remove all previous patches P0 and P1 (fixed upstream)
- add BuildRequires on pkgconfig(icu-io) and pkgconfig(libxine)
- fix permissions for *.rb and *.py files (scripts folder)
- new version: 0.5.6
  * Continuation of original package since initial author stopped development

* Fri Oct 18 2013 umeabot <umeabot> 0.5.3-4.mga4
+ Revision: 521521
- Mageia 4 Mass Rebuild

* Tue Jan 22 2013 fwang <fwang> 0.5.3-3.mga3
+ Revision: 391051
- update rpm group
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jul 02 2012 fwang <fwang> 0.5.3-2.mga3
+ Revision: 266620
- do not build xine backend
- fix more linkage
- link against x11

* Fri May 13 2011 ahmad <ahmad> 0.5.3-2.mga1
+ Revision: 97693
- Add a patch to fix the mimetypes installed by subtitlecompoer:
  o no need to duplicate the ones already available in the freedesktop specs
  o .txt files are not necessarily subtitles files

* Fri Apr 29 2011 ahmad <ahmad> 0.5.3-1.mga1
+ Revision: 93504
- imported package subtitlecomposer

